<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://makewebbetter.com/
 * @since             1.0.0
 * @package           iconwoo-integration
 *
 * @wordpress-plugin
 * Plugin Name:       iContact Pro WooCommerce Integration
 * Plugin URI:        https://makewebbetter.com/enhanced-icontactpro-woocommerce-integration
 * Description:       A very powerful plugin to integrate your WooCommerce store with iContact seamlessly.
 * Tested up to:      5.1.1
 * Version:           1.0.1
 * Author:            MakeWebBetter
 * Author URI:        https://makewebbetter.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       iconwoo
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}
$icontact_woo_activated = false;

/**
 * Checking if WooCommerce is active
 **/

if( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

	$icontact_woo_activated = true;
}

if ( $icontact_woo_activated ) {

	/**
	 * The code that runs during plugin activation.
	 */

	if( !function_exists( 'activate_icontact_woo_integration' ) ) {

		function activate_icontact_woo_integration() {

			require_once plugin_dir_path( __FILE__ ) . 'includes/class-icontact-woo-integration-activator.php';
			Icontact_Woo_Integration_Activator::activate();
		}
	}

	/**
	 * The code that runs during plugin deactivation.
	 */

	if( !function_exists( 'deactivate_icontact_woo_integration' ) ) {

		function deactivate_icontact_woo_integration() {
			
			require_once plugin_dir_path( __FILE__ ) . 'includes/class-icontact-woo-integration-deactivator.php';
			Icontact_Woo_Integration_Deactivator::deactivate();
		}
	}

	register_activation_hook( __FILE__, 'activate_icontact_woo_integration' );
	register_deactivation_hook( __FILE__, 'deactivate_icontact_woo_integration' );

	/**
	 * The core plugin class that is used to define internationalization,
	 * admin-specific hooks, and public-facing site hooks.
	 */
	require plugin_dir_path( __FILE__ ) . 'includes/class-icontact-woo-integration.php';
	/**
	 * define constants.
	 *
	 * @since 1.0.0
	*/

	function icontact_woo_define_constants() {

		icontact_define( 'ICONTACT_WOO_ABSPATH', dirname( __FILE__ ) . '/' );
		icontact_define( 'ICONTACT_WOO_URL', plugin_dir_url( __FILE__ ) . '/' );
		icontact_define( 'ICONTACT_WOO_VERSION', '1.0.0' );

	}

	/**
	 * Define constant if not already set.
	 *
	 * @param  string $name
	 * @param  string|bool $value
	 * @since 1.0.0
	*/

	function icontact_define($name, $value){
		if (!defined($name)) {
			define($name,$value);
		}
	}

	/**
	 * Setting Page Link
	 * @since    1.0.0
	 * @author  MakeWebBetter
	 * @link  https://makewebbetter.com/
	 */

	function iconwoo_admin_settings( $actions, $plugin_file ) {

		static $plugin;

		if ( !isset( $plugin ) ) {
	
			$plugin = plugin_basename ( __FILE__ );
		}

		if ( $plugin == $plugin_file ) {

			$settings = array (
				'settings' => '<a href="' . admin_url ( 'admin.php?page=icontactwoo' ) . '">' . __ ( 'Settings', 'iconwoo' ) . '</a>',
			);

			$actions = array_merge ( $settings, $actions );
		}

		return $actions;
	}

	//add link for settings
	add_filter ( 'plugin_action_links','iconwoo_admin_settings', 10, 5 );

	/**
	 * Auto Redirection to settings page after plugin activation
	 * @since    1.0.0
	 * @author  MakeWebBetter
	 * @link  https://makewebbetter.com/
	 */

	function icontact_woo_activation_redirect( $plugin){

		if ($plugin == plugin_basename( __FILE__ )) {
			
			exit(wp_redirect( admin_url('admin.php?page=icontactwoo')));
		}
	}

	//redirect to settings page as soon as plugin is activated
	add_action( 'activated_plugin' , 'icontact_woo_activation_redirect' );


	/**
	 * Begins execution of the plugin.
	 *
	 * Since everything within the plugin is registered via hooks,
	 * then kicking off the plugin from this point in the file does
	 * not affect the page life cycle.
	 *
	 * @since    1.0.0
	 */
	function run_icontact_woo_integration() {

		//define contants if not defined..
		icontact_woo_define_constants();

		$iContact_woo = new Icontact_Woo_Integration();
		$iContact_woo->run();

		$GLOBALS['icontact_woo'] = $iContact_woo;

	}
	run_icontact_woo_integration();
}
else{
	/**
	 * Show warning message if woocommerce is not install
	 * @since 1.0.0
	 * @author MakeWebBetter<webmaster@makewebbetter.com>
	 * @link https://www.makewebbetter.com/
	 */

	function icontact_woo_plugin_error_notice() {

 		?>
 		 <div class="error notice is-dismissible">
 			<p><?php _e( 'WooCommerce is not activated, Please activate WooCommerce first to install iContact WooCommerce Integration.', 'iconwoo' ); ?></p>
   		</div>
   		<style>
   		#message{display:none;}
   		</style>
   		<?php 
 	} 
 	
 	add_action( 'admin_init', 'deactivate_icontact_woo_integration' );  
 
 	
 	/**
 	 * Call Admin notices
 	 * 
 	 * @author MakeWebBetter<webmaster@makewebbetter.com>
 	 * @link https://www.makewebbetter.com/
 	 */ 	
  	function deactivate_icontact_woo_integration() {

	   deactivate_plugins( plugin_basename( __FILE__ ) );
	   add_action( 'admin_notices', 'icontact_woo_plugin_error_notice' );
	}
}