<?php

/**
 * Handles all admin ajax requests.
 *
 * @link       https://makewebbetter.com/
 * @since      1.0.0
 *
 * @package    iconwoo-integration
 * @subpackage iconwoo-integration/includes
 */

/**
 * Handles all admin ajax requests.
 *
 * All the functions required for handling admin ajax requests
 * required by the plugin.
 *
 * @package    iconwoo-integration
 * @subpackage iconwoo-integration/includes
 * @author     MakeWebBetter <webmaster@makewebbetter.com>
 */
class IcontactWooAjaxHandler {

	/**
	 * construct.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		//check authentication
		add_action('wp_ajax_icontact_woo_integration_authentication', array(&$this, 'icontact_woo_integration_authentication'));

		// get all groups request handler.
		add_action( 'wp_ajax_icontact_woo_get_groups', array( &$this, 'icontact_woo_get_groups' ) );

		// create property.
		add_action( 'wp_ajax_icontact_woo_create_group_property', array( &$this, 'icontact_woo_create_group_property' ) );

		//get group properties.
		add_action( 'wp_ajax_icontact_woo_get_group_properties', array( &$this, 'icontact_woo_get_group_properties' ) );

		//mark fields setup as completed.
		add_action('wp_ajax_icontact_woo_setup_completed', array(&$this, 'icontact_woo_setup_completed'));

		//start and go to connect tab
		add_action('wp_ajax_icontact_woo_get_started_call', array(&$this, 'icontact_woo_get_started_call'));

		//mark the user choice for fields
		add_action('wp_ajax_icontact_woo_save_user_choice', array(&$this, 'icontact_woo_save_user_choice'));

		//after connection ask for next step
		add_action('wp_ajax_iconwoo_move_to_custom_fields', array(&$this, 'iconwoo_move_to_custom_fields'));
		
		//clear the user choice for fields
		add_action( 'wp_ajax_icontact_woo_clear_user_choice', array( &$this, 'icontact_woo_clear_user_choice' ) );

		//creates single field on admin call
		add_action( 'wp_ajax_icontact_woo_create_single_field', array( &$this, 'icontact_woo_create_single_field' ) );

		//woocommerce order stauses search
		add_action( 'wp_ajax_icontact_woo_search_for_order_status', array( &$this, 'icontact_woo_search_for_order_status' ) );

		//create list in icontact
		add_action( 'wp_ajax_icontat_woo_create_global_list', array( &$this, 'icontat_woo_create_global_list' ) );	
		
	}

	//checking account authentication
	public function icontact_woo_integration_authentication(){

		$response = array('status' => true, 'message' => __('Success', 'iconwoo' ) );


		check_ajax_referer( 'iconwoo_security', 'iconwoosecurity');

		$app_id 		= Icontact_Woo_Integration::get_app_id();
		$app_username 	= Icontact_Woo_Integration::get_api_username();
		$app_password 	= Icontact_Woo_Integration::get_app_password();

		$headers 		= IcontactWooConnectionManager::get_instance()->set_headers($app_id, $app_username, $app_password);

		$account_data_ecoded = IcontactWooConnectionManager::get_instance()->get_account_info($app_id, $app_username, $app_password, $headers);

		if (isset($account_data_ecoded)) {
			
			$account_data 	= json_decode($account_data_ecoded);

			if (isset($account_data->accounts[0])) {
				
				$account_id 	= $account_data->accounts[0]->accountId;

				update_option('account_id_icontact', $account_id);
			}
		}
		
		$profile_data_encoded = IcontactWooConnectionManager::get_instance()->get_client_folders($app_id, $app_username, $app_password, $account_id, $headers);

		if (isset($profile_data_encoded)) {
			
			$profile_data 	= json_decode($profile_data_encoded);

			if (isset($profile_data->clientfolders[0])) {
				
				$folder_id 		= $profile_data->clientfolders[0]->clientFolderId;

				update_option('folder_id_icontact', $folder_id);
			}
		}

		if (empty($account_id) || empty($folder_id)) {

			$response['status'] 	= false;
			$response['message'] 	= __('Something went wrong, check your details', 'iconwoo');
		}

		if ($response['status'] == true) {
			update_option('icontact_id_verified', true);
		}
		
		echo json_encode( $response );

		wp_die();
	}

	/**
	 * getting groups for fields
	 * @since 1.0.0
	 */

	public function icontact_woo_get_groups(){

		// check the nonce sercurity.
		check_ajax_referer('iconwoo_security', 'iconwoosecurity');

		$groups = IcontactWooContactProperties::get_instance()->_get( 'groups' );

		echo json_encode( $groups );
		
		wp_die();
	}

	/**
	 * create an group property on ajax request.
	 *
	 * @since 1.0.0
	 */
	public function icontact_woo_create_group_property() {
		// check the nonce sercurity.
		check_ajax_referer('iconwoo_security', 'iconwoosecurity');

		if ( isset( $_POST[ 'groupName' ] ) && isset( $_POST[ 'propertyDetails' ] ) ) {

			$propertyDetails = $_POST[ 'propertyDetails' ];

			$privateName 	= sanitize_text_field($propertyDetails['alias']);//private name
			$displayToUser 	= sanitize_text_field($propertyDetails['isVisible']);//display to user
			$fieldType 		= sanitize_text_field($propertyDetails['type']);//public name
			$publicName 	= sanitize_text_field($propertyDetails['label']);//type of field

			$app_id 		= Icontact_Woo_Integration::get_app_id();
			$app_username 	= Icontact_Woo_Integration::get_api_username();
			$app_password 	= Icontact_Woo_Integration::get_app_password();

			$account_id 	= get_option('account_id_icontact','');
			$folder_id 		= get_option('folder_id_icontact','');

			$header 		= IcontactWooConnectionManager::get_instance()->set_headers($app_id, $app_username, $app_password);

			$response 		= IcontactWooConnectionManager::get_instance()->create_custom_contact_field($app_id, $app_username, $app_password, $account_id, $folder_id, $header, $privateName, $displayToUser, $fieldType, $publicName);

			$data = json_decode($response);
			
			if(!$data->customfields == null ) {
				
				$add_properties = get_option( "icontact-woo-fields-created", array() );
				$add_properties[] = sanitize_text_field($propertyDetails['alias']);
				update_option( "icontact-woo-fields-created", $add_properties );
				
			}

			echo json_encode( $response );
			wp_die();
		}
	}

	/**
	 * get group properties by group name.
	 *
	 * @since 1.0.0
	 */

	public function icontact_woo_get_group_properties(){
		
		check_ajax_referer('iconwoo_security', 'iconwoosecurity');

		if( isset( $_POST[ 'groupName' ] ) ) {

			$groupName 	= sanitize_text_field($_POST[ 'groupName' ]);
			$properties = IcontactWooContactProperties::get_instance()->_get( 'properties', $groupName );
		}

		$iconwoo_select_fields = Icontact_Woo_Integration::icontact_woo_user_choice();

		$filtered_properties = array();

		if( $iconwoo_select_fields == "yes" ) {

			$iconwoo_selected_properties = Icontact_Woo_Integration::icontact_woo_user_selected_fields();

			if( count( $iconwoo_selected_properties ) && !empty ( $properties ) ) {

				foreach( $properties as $single_property ) {

					if( isset( $single_property["alias"] ) ) {

						if( in_array( $single_property["alias"], $iconwoo_selected_properties ) ) {

							$filtered_properties[] = $single_property;
						}
					}
				}

				echo json_encode( $filtered_properties );
			}
		}
		else {

			echo json_encode( $properties );
		}
		
		wp_die();
	}

	/**
	 * mark setup is completed.
	 *
	 * @since 1.0.0
	 */
	public function icontact_woo_setup_completed(){

		check_ajax_referer('iconwoo_security', 'iconwoosecurity');
		update_option( 'icontact_woo_setup_completed', true );
		update_option( 'icontact_woo_version', ICONTACT_WOO_VERSION );
		return true;
		wp_die();
	}

	/**
	 * create global list in icontact after creating custom fields
	 *
	 * @since 1.0.0
	 */
    public function icontat_woo_create_global_list(){

        check_ajax_referer('iconwoo_security', 'iconwoosecurity');

        $app_id         = Icontact_Woo_Integration::get_app_id();

        $app_username   = Icontact_Woo_Integration::get_api_username();

        $app_password   = Icontact_Woo_Integration::get_app_password();

        $account_id     = get_option('account_id_icontact','');

        $folder_id      = get_option('folder_id_icontact','');

        $header         = IcontactWooConnectionManager::get_instance()->set_headers($app_id, $app_username, $app_password);

        //check if list already exists
        $name           = "mwb_global_list";

        $publicname     = "mwb global list";

        $description    = __('This is the global list with all contacts. Do not delete this list.', 'iconwoo');

        $get_list_detail = IcontactWooConnectionManager::get_instance()->get_list($app_id, $app_username, $app_password, $account_id, $folder_id, $header, $name);

        $check = json_decode($get_list_detail)->lists;

        if ($check == null) {
            	
            //if null then create list
            $created_list = IcontactWooConnectionManager::get_instance()->create_list($app_id, $app_username, $app_password, $account_id, $folder_id, $header, $name, $publicname, $description);

            if (isset($created_list)) {

                $create_list_id = json_decode($created_list);

                if (isset($create_list_id->lists[0])) {
					
                    $create_list_id = $create_list_id->lists[0]->listId;
                    update_option('icontact_mwb_global_list_id', $create_list_id);
                }
            }
		} 
		else{

            $create_list_id = json_decode($get_list_detail)->lists[0]->listId;
            update_option('icontact_mwb_global_list_id', $create_list_id);
        }
        return true;
	
	}
	/**
	 * get started on admin call
	 *
	 * @since 1.0.0
	 */
	public function icontact_woo_get_started_call() {

		check_ajax_referer( 'iconwoo_security', 'iconwoosecurity');
		update_option( 'icontact_woo_get_started', true );
		return true;
	}

	/**
	 * save user choice for fields
	 *
	 * @since 1.0.0
	 */
	public function icontact_woo_save_user_choice() {

		check_ajax_referer('iconwoo_security', 'iconwoosecurity');
		$choice = sanitize_text_field($_POST['choice']);
		update_option( 'icontact_woo_select_fields', $choice );
		return true;
	}

	/**
	 * move to custom fields
	 *
	 * @since 1.0.0
	 */
	public function iconwoo_move_to_custom_fields(){

		check_ajax_referer('iconwoo_security', 'iconwoosecurity');
		update_option('icontact_woo_move_to_custom_fields',true);
		return true;

	}

	/**
	 * clearing user choice for fields selection
	 *
	 * @since 1.0.0
	 */
	public function icontact_woo_clear_user_choice() {

		check_ajax_referer('iconwoo_security', 'iconwoosecurity');
		delete_option( 'icontact_woo_select_fields' );
		return true;		
	}

	/**
	 * creating selected single field
	 *
	 * @since 1.0.0
	 */
	public function icontact_woo_create_single_field(){

		check_ajax_referer('iconwoo_security', 'iconwoosecurity');

		$alias = sanitize_text_field($_POST['alias']);

		$all_fields = Icontact_Woo_Integration::icontact_woo_get_final_fields();

		if (is_array($all_fields) && count($all_fields)) {
			
			foreach ($all_fields as $single_property) {
				
				if (!empty($single_property['status']) && $single_property['status'] == 'false' && isset($single_property['detail']['alias']) && $single_property['detail']['alias'] == $alias ) {

					$property = $single_property[ 'detail' ];

					$privateName = $property['alias'];//private name

					$displayToUser = $property['isVisible'];//display to user

					$fieldType = $property['type'];//public name

					$publicName = $property['label'];//type of field

					$app_id = Icontact_Woo_Integration::get_app_id();
					$app_username = Icontact_Woo_Integration::get_api_username();
					$app_password = Icontact_Woo_Integration::get_app_password();

					$account_id = get_option('account_id_icontact');
					$folder_id = get_option('folder_id_icontact');

					$header = IcontactWooConnectionManager::get_instance()->set_headers($app_id, $app_username, $app_password);

					$response = IcontactWooConnectionManager::get_instance()->create_custom_contact_field($app_id, $app_username, $app_password, $account_id, $folder_id, $header, $privateName, $displayToUser, $fieldType, $publicName);

					$data = json_decode($response);

					if (!$data->customfields == null){
						
						$pre_created_fields = Icontact_Woo_Integration::icontact_woo_user_selected_fields();
						
						$pre_created_fields[] = $property['alias'];
						
						update_option( 'icontact_woo_selected_properties', $pre_created_fields );

						$add_properties = get_option( "icontact-woo-fields-created", array() );
						$add_properties[] = $property['alias'];
						
						update_option( "icontact-woo-fields-created", $add_properties );

						echo json_encode("Sucess");
					}
					else{
						echo json_encode($data->warnings);
					}
					wp_die();
				}
			}
		}
	}

	/**
	 * searching for order status
	 * @since 1.0.0
	 */

	public function icontact_woo_search_for_order_status() {

		$order_statuses = wc_get_order_statuses();
		$return = array();

		if( !empty( $order_statuses ) ) {

			foreach ( $order_statuses as $status_key => $single_status ) {

				$return[] = array( $status_key, $single_status );
			}
		}

		echo json_encode( $return );

		wp_die();
	}

}

new IcontactWooAjaxHandler();