<?php
/**
 * All api GET/POST functionalities.
 *
 * @link       https://makewebbetter.com/
 * @since      1.0.0
 *
 * @package    iconwoo-integration
 * @subpackage iconwoo-integration/includes
 */

/**
 * Handles all icontact api reqests/response related functionalities of the plugin.
 *
 * Provide a list of functions to manage all the requests
 * that needs in our integration to get/fetch data
 * from/to icontact.
 *
 * @package    iconwoo-integration
 * @subpackage iconwoo-integration/includes
 * @author     MakeWebBetter <webmaster@makewebbetter.com>
 */

class IcontactWooConnectionManager{

        protected static $_instance = null;

        public static function get_instance(){

                if ( is_null( self::$_instance ) ) {

                        self::$_instance = new self();
                }

                return self::$_instance;
        }

        //set header for api calls
        function set_headers($app_id, $user, $pass) {
                $headers = array(
                        'Accept: application/json',
                        'Content-Type: application/json',
                        'Api-Version: 2.2',
                        'Api-AppId: ' . $app_id,
                        'Api-Username: ' . $user,
                        'Api-Password: ' . $pass
                );

        return $headers;
        } 

        //get icontact account info
        function get_account_info($app_id, $user, $pass, $headers) {

                $url    = "https://api.icpro.co/icp/a/";
                $ch     = curl_init($url);
                curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
                curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

                $response = curl_exec($ch);

                if (curl_errno($ch)) echo curl_error($ch);
                curl_close($ch);

                $message = __('Fetching account id', 'iconwoo');
                $this->icontact_woo_create_log($message, $url, $response);

                return $response;
                
        }

        //get client folders after authentication
        function get_client_folders($app_id, $user, $pass, $account_id, $headers) {

                $url    = "https://api.icpro.co/icp/a/$account_id/c/";
                $ch     = curl_init($url);
                curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
                curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

                $response = curl_exec($ch);

                if (curl_errno($ch)) echo curl_error($ch);
                curl_close($ch);

                $message = __('Fetching client folders id', 'iconwoo');
                $this->icontact_woo_create_log($message, $url, $response);

                return $response;
        }

        function create_custom_contact_field($app_id, $user, $pass, $account_id, $folder_id, $header, $privateName, $displayToUser, $fieldType, $publicName = null){

                $custom_field_data = array(
                        'privateName'   => $privateName,
                        'displayToUser' => $displayToUser,
                        'fieldType'     => $fieldType
                        );

                if (!empty($publicName)) {
                        
                        $custom_field_data['publicName'] = $publicName;
                }

                $data = json_encode(array($custom_field_data));
                $url  = "https://api.icpro.co/icp/a/$account_id/c/$folder_id/customfields/";
                $ch   = curl_init($url);
                curl_setopt($ch, CURLOPT_HTTPHEADER, $header);
                curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
                curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
                
                $response = curl_exec($ch);
                $status_code = @curl_getinfo($ch, CURLINFO_HTTP_CODE);
                $curl_errors = curl_error($ch);   
             
                curl_close($ch);

                $message = __('creating custom field', 'iconwoo');
                $this->icontact_woo_create_log($message, $url, $response);

                return $response;
        }

        //get the details of existing account
        function get_contact_info($app_id, $user, $pass, $account_id, $folder_id,$headers, $email_id){

            $url = "https://api.icpro.co/icp/a/$account_id/c/$folder_id/contacts?email=$email_id";
            $ch = curl_init($url);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            $response = curl_exec($ch);

            if (curl_errno($ch)) echo curl_error($ch);
            curl_close($ch);

            $message = __('Fetching Contact Information', 'iconwoo');
            $this->icontact_woo_create_log($message, $url, $response);

            return $response;

        }

        //create new contact 
        function create_contact($app_id, $user, $pass, $account_id, $folder_id, $headers, $properties){

            $contact_data = array();

            foreach ($properties as $key => $value) {

                if ($key == 'mwb_customer_group') {
                    
                    $contact_data[$key] = implode( ';', $value );
                    
                }
                else{
                    $contact_data[$key] = $value;
                }
            }
                
            $data = json_encode(array($contact_data));
            $url = "https://api.icpro.co/icp/a/$account_id/c/$folder_id/contacts/";
            $ch = curl_init($url);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
             curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            $response = curl_exec($ch);

            if (curl_errno($ch)) echo curl_error($ch);
            curl_close($ch);

            $message = __('Creating new contact and giving custom field data', 'iconwoo');
            $this->icontact_woo_create_log($message, $url, $response);

            return $response;
        }

        //update existing contact
        function update_contact($app_id, $user, $pass, $account_id, $folder_id, $headers, $properties, $email_id){
                
                $contact_data = array();
            
                foreach ($properties as $key => $value) {

                    if ( $key == 'mwb_customer_group' ) {
                        
                        $contact_data[$key] = implode( ';', $value );
                        
                    }
                    else{

                        $contact_data[$key] = $value;
                    }
                }
                $data = json_encode(array($contact_data));
                $url = "https://api.icpro.co/icp/a/$account_id/c/$folder_id/contacts?email=$email_id";
                $ch = curl_init($url);
                curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
                curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
                curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

                $response = curl_exec($ch);

                if (curl_errno($ch)) echo curl_error($ch);
                curl_close($ch);

                $message = __('updating contact', 'iconwoo');
                $this->icontact_woo_create_log($message, $url, $response);

                return $response;
        }
        //get list
        public function get_list($app_id, $user, $pass, $account_id, $folder_id, $headers, $name){

            $url = "https://api.icpro.co/icp/a/$account_id/c/$folder_id/lists?name=$name";
            $ch = curl_init($url);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            $response = curl_exec($ch);

            if (curl_errno($ch)) echo curl_error($ch);
            curl_close($ch);

            $message = __('Checking if mwb_global_list is already present.', 'iconwoo');
            $this->icontact_woo_create_log($message, $url, $response);

            return $response;
        }
        //create list
        public function create_list($app_id, $user, $pass, $account_id, $folder_id, $headers, $name, $publicname, $description){

            $list_data = array(
                'name'          => $name,
                'publicname'    => $publicname,
                'description'   => $description
                );
            $data       = json_encode(array($list_data));
            $url        = "https://api.icpro.co/icp/a/$account_id/c/$folder_id/lists/";
            $ch         = curl_init($url);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            $response   = curl_exec($ch);

            if (curl_errno($ch)) echo curl_error($ch);
            curl_close($ch);

            $message    = __('Creating global list in iContact.', 'iconwoo');
            $this->icontact_woo_create_log($message, $url, $response);

            return $response;
        }

        //assign contact to list
        public function add_contact_to_list($app_id, $user, $pass, $account_id, $folder_id, $headers, $contact_id, $list_id){

            $subscription_data = array(
                'contactId' => $contact_id,
                'listId'    => $list_id,
                'status'    => 'normal'
            );

            $data       = json_encode(array($subscription_data));
            $url        = "https://api.icpro.co/icp/a/$account_id/c/$folder_id/subscriptions/";
            $ch         = curl_init($url);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            $response   = curl_exec($ch);

            if (curl_errno($ch)) echo curl_error($ch);
            curl_close($ch);

            $message    = __('Adding contact to mwb_global_list.', 'iconwoo');
            $this->icontact_woo_create_log($message, $url, $response);

            return $response;
        }

        /**
         * create log of requests.
         * 
         * @param  string    $message     icontact log message.
         * @param  string    $url         icontact acceptable url.
         * @param  array     $response    icontact response array.
         * @access public
         * @since 1.0.0
         */
        public function icontact_woo_create_log( $message, $url, $response ) {
            
            $log_enable = get_option('icontact_woo_log', 'no');

            if ($log_enable == "yes") {


                $log_dir = WC_LOG_DIR.'icontact-woo-logs.log';

            if (!is_dir($log_dir)) {

                @fopen( WC_LOG_DIR.'icontact-woo-logs.log', 'a' );
            }

            $log  = "Website: ".$_SERVER['REMOTE_ADDR'].PHP_EOL.
                    'Time: '.current_time("F j, Y  g:i a").PHP_EOL.
                    "Process: ".$message.PHP_EOL.
                    "URL: ".$url.PHP_EOL.
                    "Response: ".json_encode( json_decode( $response ) ).PHP_EOL.
                    "-----------------------------------".PHP_EOL;

            file_put_contents($log_dir, $log, FILE_APPEND);
            }
            
        }
}
